@@ -20,5 +20,5 @@ test_that("get_filled_drops works", {
                    get_filled_drops(plate, "A05", border_A05))
   
   expect_equal(get_filled_drops(plate, "A05"),
-                   readr::read_csv(file.path(dir, "A05_filled.csv")))
+                   readr::read_csv(file.path(dir, "A05_filled.csv"), col_types = "ii"))
 })
